==> heimdal-libraries-1.2.1-i486-3gsb.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libkadm5srv.so.8 )
( cd usr/lib ; ln -sf libkadm5srv.so.8.0.1 libkadm5srv.so.8 )
( cd usr/lib ; rm -rf libkrb5.so.25 )
( cd usr/lib ; ln -sf libkrb5.so.25.0.0 libkrb5.so.25 )
( cd usr/lib ; rm -rf libwind.so )
( cd usr/lib ; ln -sf libwind.so.0.0.0 libwind.so )
( cd usr/lib ; rm -rf libotp.so.0 )
( cd usr/lib ; ln -sf libotp.so.0.1.5 libotp.so.0 )
( cd usr/lib ; rm -rf libkadm5clnt.so.7 )
( cd usr/lib ; ln -sf libkadm5clnt.so.7.0.1 libkadm5clnt.so.7 )
( cd usr/lib ; rm -rf libroken.so )
( cd usr/lib ; ln -sf libroken.so.18.1.0 libroken.so )
( cd usr/lib ; rm -rf windc.so.0 )
( cd usr/lib ; ln -sf windc.so.0.0.0 windc.so.0 )
( cd usr/lib ; rm -rf libkrb5.so )
( cd usr/lib ; ln -sf libkrb5.so.25.0.0 libkrb5.so )
( cd usr/lib ; rm -rf libasn1.so )
( cd usr/lib ; ln -sf libasn1.so.8.0.0 libasn1.so )
( cd usr/lib ; rm -rf libeditline.so )
( cd usr/lib ; ln -sf libeditline.so.0.0.0 libeditline.so )
( cd usr/lib ; rm -rf libotp.so )
( cd usr/lib ; ln -sf libotp.so.0.1.5 libotp.so )
( cd usr/lib ; rm -rf libgssapi.so.2 )
( cd usr/lib ; ln -sf libgssapi.so.2.0.0 libgssapi.so.2 )
( cd usr/lib ; rm -rf libheimntlm.so.0 )
( cd usr/lib ; ln -sf libheimntlm.so.0.1.0 libheimntlm.so.0 )
( cd usr/lib ; rm -rf libroken.so.18 )
( cd usr/lib ; ln -sf libroken.so.18.1.0 libroken.so.18 )
( cd usr/lib ; rm -rf libkafs.so.0 )
( cd usr/lib ; ln -sf libkafs.so.0.5.1 libkafs.so.0 )
( cd usr/lib ; rm -rf libkadm5srv.so )
( cd usr/lib ; ln -sf libkadm5srv.so.8.0.1 libkadm5srv.so )
( cd usr/lib ; rm -rf libgssapi.so )
( cd usr/lib ; ln -sf libgssapi.so.2.0.0 libgssapi.so )
( cd usr/lib ; rm -rf libkdc.so.2 )
( cd usr/lib ; ln -sf libkdc.so.2.0.0 libkdc.so.2 )
( cd usr/lib ; rm -rf windc.so )
( cd usr/lib ; ln -sf windc.so.0.0.0 windc.so )
( cd usr/lib ; rm -rf libkafs.so )
( cd usr/lib ; ln -sf libkafs.so.0.5.1 libkafs.so )
( cd usr/lib ; rm -rf libwind.so.0 )
( cd usr/lib ; ln -sf libwind.so.0.0.0 libwind.so.0 )
( cd usr/lib ; rm -rf libeditline.so.0 )
( cd usr/lib ; ln -sf libeditline.so.0.0.0 libeditline.so.0 )
( cd usr/lib ; rm -rf libasn1.so.8 )
( cd usr/lib ; ln -sf libasn1.so.8.0.0 libasn1.so.8 )
( cd usr/lib ; rm -rf libkdc.so )
( cd usr/lib ; ln -sf libkdc.so.2.0.0 libkdc.so )
( cd usr/lib ; rm -rf libsl.so.0 )
( cd usr/lib ; ln -sf libsl.so.0.2.1 libsl.so.0 )
( cd usr/lib ; rm -rf libhdb.so.9 )
( cd usr/lib ; ln -sf libhdb.so.9.2.0 libhdb.so.9 )
( cd usr/lib ; rm -rf libhx509.so )
( cd usr/lib ; ln -sf libhx509.so.4.0.0 libhx509.so )
( cd usr/lib ; rm -rf libkadm5clnt.so )
( cd usr/lib ; ln -sf libkadm5clnt.so.7.0.1 libkadm5clnt.so )
( cd usr/lib ; rm -rf libheimntlm.so )
( cd usr/lib ; ln -sf libheimntlm.so.0.1.0 libheimntlm.so )
( cd usr/lib ; rm -rf libsl.so )
( cd usr/lib ; ln -sf libsl.so.0.2.1 libsl.so )
( cd usr/lib ; rm -rf libhdb.so )
( cd usr/lib ; ln -sf libhdb.so.9.2.0 libhdb.so )
( cd usr/lib ; rm -rf libhx509.so.4 )
( cd usr/lib ; ln -sf libhx509.so.4.0.0 libhx509.so.4 )

# needed for API compatibility with MIT Krb5
(cd usr/include/gssapi; ln -fs gssapi.h gssapi_generic.h);

# Install new info files
if [ -x usr/bin/install-info ]; then
  usr/bin/install-info usr/info/hx509.info.gz usr/info/dir >/dev/null 2>&1
  usr/bin/install-info usr/info/heimdal.info.gz usr/info/dir >/dev/null 2>&1
fi

==> heimdal-libraries-1.3.3-i486-2gsb.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libotp.so.0 )
( cd usr/lib ; ln -sf libotp.so.0.1.5 libotp.so.0 )
( cd usr/lib ; rm -rf libhdb.so )
( cd usr/lib ; ln -sf libhdb.so.9.2.0 libhdb.so )
( cd usr/lib ; rm -rf libgssapi.so )
( cd usr/lib ; ln -sf libgssapi.so.2.0.0 libgssapi.so )
( cd usr/lib ; rm -rf libkdc.so )
( cd usr/lib ; ln -sf libkdc.so.2.0.0 libkdc.so )
( cd usr/lib ; rm -rf libkadm5clnt.so.7 )
( cd usr/lib ; ln -sf libkadm5clnt.so.7.0.1 libkadm5clnt.so.7 )
( cd usr/lib ; rm -rf libkdc.so.2 )
( cd usr/lib ; ln -sf libkdc.so.2.0.0 libkdc.so.2 )
( cd usr/lib ; rm -rf libotp.so )
( cd usr/lib ; ln -sf libotp.so.0.1.5 libotp.so )
( cd usr/lib ; rm -rf libroken.so )
( cd usr/lib ; ln -sf libroken.so.18.1.0 libroken.so )
( cd usr/lib ; rm -rf libasn1.so.8 )
( cd usr/lib ; ln -sf libasn1.so.8.0.0 libasn1.so.8 )
( cd usr/lib ; rm -rf libhx509.so.5 )
( cd usr/lib ; ln -sf libhx509.so.5.0.0 libhx509.so.5 )
( cd usr/lib ; rm -rf libheimntlm.so )
( cd usr/lib ; ln -sf libheimntlm.so.0.1.0 libheimntlm.so )
( cd usr/lib ; rm -rf libhdb.so.9 )
( cd usr/lib ; ln -sf libhdb.so.9.2.0 libhdb.so.9 )
( cd usr/lib ; rm -rf libkadm5srv.so )
( cd usr/lib ; ln -sf libkadm5srv.so.8.0.1 libkadm5srv.so )
( cd usr/lib ; rm -rf libwind.so.0 )
( cd usr/lib ; ln -sf libwind.so.0.0.0 libwind.so.0 )
( cd usr/lib ; rm -rf libheimntlm.so.0 )
( cd usr/lib ; ln -sf libheimntlm.so.0.1.0 libheimntlm.so.0 )
( cd usr/lib ; rm -rf libkrb5.so.26 )
( cd usr/lib ; ln -sf libkrb5.so.26.0.0 libkrb5.so.26 )
( cd usr/lib ; rm -rf libroken.so.18 )
( cd usr/lib ; ln -sf libroken.so.18.1.0 libroken.so.18 )
( cd usr/lib ; rm -rf libasn1.so )
( cd usr/lib ; ln -sf libasn1.so.8.0.0 libasn1.so )
( cd usr/lib ; rm -rf libkadm5clnt.so )
( cd usr/lib ; ln -sf libkadm5clnt.so.7.0.1 libkadm5clnt.so )
( cd usr/lib ; rm -rf libwind.so )
( cd usr/lib ; ln -sf libwind.so.0.0.0 libwind.so )
( cd usr/lib ; rm -rf libhx509.so )
( cd usr/lib ; ln -sf libhx509.so.5.0.0 libhx509.so )
( cd usr/lib ; rm -rf windc.so.0 )
( cd usr/lib ; ln -sf windc.so.0.0.0 windc.so.0 )
( cd usr/lib ; rm -rf windc.so )
( cd usr/lib ; ln -sf windc.so.0.0.0 windc.so )
( cd usr/lib ; rm -rf libeditline.so )
( cd usr/lib ; ln -sf libeditline.so.0.0.0 libeditline.so )
( cd usr/lib ; rm -rf libkafs.so )
( cd usr/lib ; ln -sf libkafs.so.0.5.1 libkafs.so )
( cd usr/lib ; rm -rf libkafs.so.0 )
( cd usr/lib ; ln -sf libkafs.so.0.5.1 libkafs.so.0 )
( cd usr/lib ; rm -rf libkadm5srv.so.8 )
( cd usr/lib ; ln -sf libkadm5srv.so.8.0.1 libkadm5srv.so.8 )
( cd usr/lib ; rm -rf libeditline.so.0 )
( cd usr/lib ; ln -sf libeditline.so.0.0.0 libeditline.so.0 )
( cd usr/lib ; rm -rf libgssapi.so.2 )
( cd usr/lib ; ln -sf libgssapi.so.2.0.0 libgssapi.so.2 )
( cd usr/lib ; rm -rf libsl.so )
( cd usr/lib ; ln -sf libsl.so.0.2.1 libsl.so )
( cd usr/lib ; rm -rf libkrb5.so )
( cd usr/lib ; ln -sf libkrb5.so.26.0.0 libkrb5.so )
( cd usr/lib ; rm -rf libsl.so.0 )
( cd usr/lib ; ln -sf libsl.so.0.2.1 libsl.so.0 )

# needed for API compatibility with MIT Krb5
(cd usr/include/gssapi; ln -fs gssapi.h gssapi_generic.h);

# Install new info files
if [ -x usr/bin/install-info ]; then
  usr/bin/install-info usr/info/hx509.info.gz usr/info/dir >/dev/null 2>&1
  usr/bin/install-info usr/info/heimdal.info.gz usr/info/dir >/dev/null 2>&1
fi
